import { randomUUID } from 'crypto';
import { createSlug } from '../../utilities/slug.js';
export default function (options) {
    const opts = {
        levels: ['h1', 'h2', 'h3', 'h4', 'h5', 'h6'],
        className: 'anchor-heading',
        within: 'main',
        ...options
    };
    return {
        transform: doc => {
            const within = doc.querySelector(opts.within);
            if (!within) {
                return doc;
            }
            within.querySelectorAll('h1, h2, h3, h4, h5, h6').forEach((heading) => {
                const hasAnchor = heading.querySelector('a');
                const anchor = doc.createElement('a');
                const slug = createSlug(heading.textContent ?? '') ?? randomUUID().slice(-12);
                let id = slug;
                let suffix = 0;
                while (doc.getElementById(id) !== null) {
                    id = `${slug}-${++suffix}`;
                }
                if (hasAnchor || !id)
                    return;
                heading.setAttribute('id', id);
                anchor.setAttribute('href', `#${encodeURIComponent(id)}`);
                if (opts.className) {
                    anchor.classList.add(opts.className);
                }
                if (opts.levels?.includes(heading.tagName.toLowerCase())) {
                    const headingHtml = heading.innerHTML;
                    anchor.innerHTML = headingHtml;
                    heading.innerHTML = anchor.outerHTML;
                }
            });
            return doc;
        }
    };
}
