import fs from 'fs/promises';
import path from 'path';
import chalk from 'chalk';
import Handlebars from 'handlebars';
import { themeDir } from '../index.js';
import { TemplateRenderError } from './errors.js';
import { render as renderMarkdown } from './markdown.js';
const templateCache = new Map();
export async function render(page, data, config) {
    const templateName = 'default';
    const file = path.join(themeDir, `${templateName}.hbs`);
    const source = await fs.readFile(file, 'utf8');
    const filename = path.relative(config.inputDir, page.inputFile);
    let template;
    if (templateCache.has(templateName) && !config.dev) {
        template = templateCache.get(templateName);
    }
    else {
        template = Handlebars.compile(source);
        templateCache.set(templateName, template);
    }
    try {
        const contentTemplate = Handlebars.compile(data.content);
        data.content = renderMarkdown(contentTemplate(Object.assign(data, { content: undefined })));
    }
    catch (err) {
        throw new TemplateRenderError(page, `Unable to render content from "${filename}":\n\n${chalk.yellow(err)}`);
    }
    try {
        return template(data);
    }
    catch (err) {
        throw new TemplateRenderError(page, `Unable to render template "${templateName}" in "${filename}":\n\n${chalk.yellow(err)}`);
    }
}
export function registerHelper(name, callback) {
    Handlebars.registerHelper(name, callback);
}
export function registerPartial(name, htmlTemplate) {
    Handlebars.registerPartial(name, htmlTemplate);
}
